
package Apache::MP3::L10N::sk;  # Slovak
use strict;
use Apache::MP3::L10N;
use vars qw($VERSION @ISA %Lexicon);
@ISA = qw(Apache::MP3::L10N);
sub language_tag {__PACKAGE__->SUPER::language_tag}

# Translators for this module, in no particular order:
# Radovan Hrabcak duffy@duffy.sk

sub encoding { "iso-8859-2" }   # Latin-2
  # Change as necessary if you use a different encoding

%Lexicon = (
 '_VERSION' => __PACKAGE__ . ' v' . 
 ($VERSION=   '20020612'), # Last modified


 # These are links as well as button text:
 'Play All' => "Prehrať všetko",
 'Shuffle All' => 'Náhodné poradie',  # Stream all in random order
 'Stream All' => 'Prehrať všetko', # What's the difference between Strema All and Play All?

 # This one in just button text
 'Play Selected' => 'Prehrať vybrané',

 "In this demo, streaming is limited to approximately [quant,_1,second,seconds]."
  => "V tomto deme, je prehrávanie obmedzené; na približne [quant,_1,sekundu,sekúnd].",
  # In [quant,_1,seconde,secondes], the seconde is the singular form, and the secondes is the plural.

 # Headings:
 'CD Directories ([_1])' => 'CD adresáre ([_1])',
 'Playlists ([_1])' => 'Playlisty (.m3u) ([_1])',        # .m3u files
 'Song List ([_1])' => 'Zoznam skladieb ([_1])', # i.e., file list


 'Playlist' => 'Playlist',
 'Select' => 'Vybrať',

 'fetch'  => 'uložiť', # Send/download/save this file
 'stream' => 'hrať',    # this file

 'Shuffle'  => 'Náhodné poradie',  # a subdirectory, recursively
 'Stream'   => 'Prehrať',            # a subdirectory, recursively

 # Label for a link to "http://[servername]/"
 'Home' => 'Na začiatok',

 # Credits
 "_CREDITS_before_author" => 'Apache::MP3 bol napísaný ',
 "_CREDITS_author"        => 'Lincolnom D. Steinom',
 "_CREDITS_after_author"  => ".",


 'unknown' => '?',
   # Used when a file doesn't specify its album name, artist name,
   # year of release, etc.


 # Metadata fields:
 'Artist' => "Interpret",
 'Comment' => "Poznámky",
 'Duration' => "Dĺžka",
 'Filename' => "Názov",
 'Genre' => "Žáner",  # i.e., what kind of music
 'Album' => "Album",
 'Min' => "min.",  # abbreviation for "minutes"
 'Track' => "Skladba",  # just the track number (not the track name)
 'Sec' => "sek.",  # abbreviation for "seconds"
 'Seconds' => "Sekúnd",
 'Title' => "Názov",
 'Year' => "Rok",

 'Samplerate' => "Kvalita pôvodného zvuku",
 'Bitrate' => "Kvalita zvuku (bitrate)",


 # Now the stuff for the help page:

 'Quick Help Summary' => "Prehľad nápovedy",
  # page title as well as the text we use for linking to that page

 "= Stream all songs" => "= Prerhať; všetky skladby",
 "= Shuffle-play all Songs" => "= Prerhať všetky skladby v náhodnom poradí",
 "= Go to earlier directory" => "= O úroveň vyššie",
       # i.e., just a link to ../ or higher
 "= Stream contents" => "= Prehrať obsah",
 "= Enter directory" => "= Do adresára",
 "= Stream this song" => "= Prehrať túto skladbu",
 "= Select for streaming" => "= Vybrať na prehratie",
 "= Download this song" => "= Uložiť túto skladbu",
 "= Stream this song" => "= Prehrať túto skladbu",
 "= Sort by field" => "= Usporiadať podľa",
    # "sort" in the sense of ordering, not separating out.
);

1;

